s6: the s6-tai64n program
Keywords: s6 command s6-tai64n filter timestamp TAI64 TAI64N

s6
Software
skarnet.org

# The s6-tai64n program

s6-tai64n acts as a filter, reading from stdin and writing to stdout. It prepends lines with a TAI64N timestamp and a space.

## Interface

         s6-tai64n

- s6-tai64n exits 0 when it sees the end of stdin. If there's an unfinished line, s6-tai64n processes it, adds a newline character to it, and writes it before exiting.

## Notes

s6-tai64n does neither "line buffering" nor "block buffering". It does optimal buffering, i.e. it flushes its output buffer every time it risks blocking on input. Every filter should behave this way, whether its output is a tty or not: it's simpler and more efficient in every case.